import sinon from 'sinon';
import { service as creditLinesService } from './creditLines.js';

const urlParams = { document: '07807807888', status: 'Active' };

describe('Credit Lines Module', () => {
  it('Should have methods after initialization.', () => {
    const service = creditLinesService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLinesService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = creditLinesService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/credit/07807807888/credit-lines?status=Active');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLinesService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
