import sinon from 'sinon';
import { service as merchantPermissionsService } from './merchantPermissions';

const urlParams = {
  affiliationCode: 123456,
};

describe(' Merchant permissions module', () => {
  it('Should have methods after initialization.', () => {
    const service = merchantPermissionsService();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = merchantPermissionsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = merchantPermissionsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('/v0/merchant/contract/123456/permissions');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = merchantPermissionsService(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
