import sinon from 'sinon';
import { service as permission } from './permission.js';

let urlParams;
let spy;

describe('Users Permission Module', () => {
  beforeEach(() => {
    spy = sinon.spy();
    urlParams = {
      userIdentifier: 'user@stone.com',
      permission: 'ADD_USER',
    };
  });

  afterEach(() => {
    spy = undefined;
    urlParams = undefined;
  });

  it('Should have methods after initialization.', () => {
    const service = permission();
    expect(service.get).to.be.a('function');
    expect(service.post).to.be.a('function');
    expect(service.delete).to.be.a('function');
  });

  it('Should call get request once with correct params.', () => {
    const getRequest = () => spy;
    const service = permission(getRequest);
    service.get(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });

  it('Should call post request once with correct params.', () => {
    const postRequest = () => spy;
    const service = permission(undefined, postRequest);
    service.post(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });

  it('Should call delete request once with correct params.', () => {
    const deleteRequest = () => spy;
    const service = permission(undefined, undefined, deleteRequest);
    service.delete(urlParams);

    expect(spy).to.have.been.calledOnceWith(urlParams);
  });

  it('Should call get request and return a valid URL.', () => {
    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = permission(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/portal/users/user@stone.com/permissions/ADD_USER');
  });

  it('Should call post request and return a valid URL.', () => {
    const postRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = permission(undefined, postRequest);

    service.post(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/portal/users/user@stone.com/permissions/ADD_USER');
  });

  it('Should call delete request and return a valid URL.', () => {
    const deleteRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = permission(undefined, undefined, deleteRequest);

    service.delete(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/portal/users/user@stone.com/permissions/ADD_USER');
  });
});
